@@ -10,7 +10,7 @@ use Net::SSLLabs::Endpoint();
 use Net::SSLLabs::StatusCodes();
 use URI::Escape();
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
     my ($class) = @_;
@@ -35,14 +35,28 @@ sub info {
     }
 }
 
+sub _translate_params {
+    my ( $self, %params ) = @_;
+    my %translated_params;
+    foreach my $key ( sort { $a cmp $b } sort keys %params ) {
+        if ( defined $params{$key} ) {
+            my $translated_key = $key;
+            $translated_key =~ s/_([[:lower:]])/uc $1/egsmx;
+            $translated_params{$translated_key} = $params{$key};
+        }
+    }
+    return %translated_params;
+}
+
 sub analyze {
     my ( $self, %params ) = @_;
-    my $url = $self->{url} . 'analyze?' . (
+    my %translated_params = $self->_translate_params(%params);
+    my $url               = $self->{url} . 'analyze?' . (
         join q[&],
         map {
                 URI::Escape::uri_escape_utf8($_) . q[=]
-              . URI::Escape::uri_escape_utf8( $params{$_} )
-        } keys %params
+              . URI::Escape::uri_escape_utf8( $translated_params{$_} )
+        } sort _sort_ssllabs_params keys %translated_params
     );
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
@@ -58,14 +72,30 @@ sub analyze {
     return;
 }
 
+sub _sort_ssllabs_params {
+    if ( $a eq 'host' ) {
+        return -1;
+    }
+    elsif ( $b eq 'host' ) {
+        return 1;
+    } elsif ( $a eq 's' ) {
+        return -1;
+    } elsif ( $b eq 's' ) {
+        return 1;
+    }else {
+        return $a cmp $b;
+    }
+}
+
 sub get_endpoint_data {
     my ( $self, %params ) = @_;
-    my $url = $self->{url} . 'getEndpointData?' . (
+    my %translated_params = $self->_translate_params(%params);
+    my $url               = $self->{url} . 'getEndpointData?' . (
         join q[&],
         map {
                 URI::Escape::uri_escape_utf8($_) . q[=]
-              . URI::Escape::uri_escape_utf8( $params{$_} )
-        } keys %params
+              . URI::Escape::uri_escape_utf8( $translated_params{$_} )
+        } sort _sort_ssllabs_params keys %translated_params
     );
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
@@ -95,11 +125,11 @@ __END__
 
 =head1 NAME
 
-Net::SSLLabs - An interface to the L<https://www.ssllabs.com/ssltest> service
+Net::SSLLabs - An interface to the ssllabs.com service
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
@@ -142,15 +172,15 @@ Parameters:
 
 =item * publish - set to "on" if assessment results should be published on the public results boards; optional, defaults to "off".
 
-=item * startNew - if set to "on" then cached assessment results are ignored and a new assessment is started. However, if there's already an assessment in progress, its status is delivered instead. This parameter should be used only once to initiate a new assessment; further invocations should omit it to avoid causing an assessment loop.
+=item * start_new - if set to "on" then cached assessment results are ignored and a new assessment is started. However, if there's already an assessment in progress, its status is delivered instead. This parameter should be used only once to initiate a new assessment; further invocations should omit it to avoid causing an assessment loop.
 
-=item * fromCache - always deliver cached assessment reports if available; optional, defaults to "off". This parameter is intended for when you don't want to wait for assessment results. Can't be used at the same time as the startNew parameter.
+=item * from_cache - always deliver cached assessment reports if available; optional, defaults to "off". This parameter is intended for when you don't want to wait for assessment results. Can't be used at the same time as the start_new parameter.
 
-=item * maxAge - maximum report age, in hours, if retrieving from cache (fromCache parameter set).
+=item * max_age - maximum report age, in hours, if retrieving from cache (from_cache parameter set).
 
 =item * all - by default this call results only summaries of individual endpoints. If this parameter is set to "on", full information will be returned. If set to "done", full information will be returned only if the assessment is complete (status is READY or ERROR).
 
-=item * ignoreMismatch - set to "on" to proceed with assessments even when the server certificate doesn't match the assessment host name. Set to off by default. Please note that this parameter is ignored if a cached report is returned.
+=item * ignore_mismatch - set to "on" to proceed with assessments even when the server certificate doesn't match the assessment host name. Set to "off" by default. Please note that this parameter is ignored if a cached report is returned.
 
 =back 
 
@@ -166,7 +196,7 @@ Parameters:
 
 =item * s - endpoint IP address
 
-=item * fromCache - see above.
+=item * from_cache - see above.
 
 =back 
 
